@@ -1,12 +1,19 @@
 import sys
 import tkinter
 from distutils.version import StrictVersion as Version
-import darkdetect
+from typing import Callable
 
-if Version(darkdetect.__version__) < Version("0.3.1"):
-    sys.stderr.write("WARNING: You have to update the darkdetect library: pip3 install --upgrade darkdetect\n")
-    if sys.platform != "darwin":
-        exit()
+try:
+    import darkdetect
+
+    if Version(darkdetect.__version__) < Version("0.3.1"):
+        sys.stderr.write("WARNING: You have to upgrade the darkdetect library: pip3 install --upgrade darkdetect\n")
+        if sys.platform != "darwin":
+            exit()
+except ImportError as err:
+    raise err
+except Exception:
+    sys.stderr.write("customtkinter.appearance_mode_tracker warning: failed to import darkdetect")
 
 
 class AppearanceModeTracker:
@@ -14,6 +21,7 @@ class AppearanceModeTracker:
     callback_list = []
     root_tk_list = []
     update_loop_running = False
+    update_loop_interval = 500  # milliseconds
 
     appearance_mode_set_by = "system"
     appearance_mode = 0  # Light (standard)
@@ -28,7 +36,7 @@ class AppearanceModeTracker:
                 cls.update_callbacks()
 
     @classmethod
-    def add(cls, callback, widget=None):
+    def add(cls, callback: Callable, widget=None):
         cls.callback_list.append(callback)
 
         if widget is not None:
@@ -41,11 +49,11 @@ class AppearanceModeTracker:
                     cls.update_loop_running = True
 
     @classmethod
-    def remove(cls, callback):
+    def remove(cls, callback: Callable):
         cls.callback_list.remove(callback)
 
     @staticmethod
-    def detect_appearance_mode():
+    def detect_appearance_mode() -> int:
         try:
             if darkdetect.theme() == "Dark":
                 return 1  # Dark
@@ -91,7 +99,7 @@ class AppearanceModeTracker:
         # find an existing tkinter.Tk object for the next call of .after()
         for root_tk in cls.root_tk_list:
             try:
-                root_tk.after(200, cls.update)
+                root_tk.after(cls.update_loop_interval, cls.update)
                 return
             except Exception:
                 continue
@@ -99,11 +107,11 @@ class AppearanceModeTracker:
         cls.update_loop_running = False
 
     @classmethod
-    def get_mode(cls):
+    def get_mode(cls) -> int:
         return cls.appearance_mode
 
     @classmethod
-    def set_appearance_mode(cls, mode_string):
+    def set_appearance_mode(cls, mode_string: str):
         if mode_string.lower() == "dark":
             cls.appearance_mode_set_by = "user"
             new_appearance_mode = 1
@@ -122,6 +130,3 @@ class AppearanceModeTracker:
 
         elif mode_string.lower() == "system":
             cls.appearance_mode_set_by = "system"
-
-
-AppearanceModeTracker.init_appearance_mode()
